import SQLite from "react-native-sqlite-storage";
SQLite.DEBUG(true);
SQLite.enablePromise(true);
const database_name = "Reactoffline.db";
const database_version = "1.0";
const database_displayname = "SQLite React Offline Database";
const database_size = 200000;

export default class ApprovedProjectsListOffline {
    //Create or Initialize the DB and ApprovedProjectsList Table or Open DataBase
    initDB() {
        let db;
        return new Promise((resolve) => {
            // console.warn("Plugin integrity check ...");
            SQLite.echoTest()
                .then(() => {
                    // console.warn("Integrity check passed ...");
                    console.log("Opening database ...");
                    SQLite.openDatabase(
                        database_name,
                        database_version,
                        database_displayname,
                        database_size
                    )
                        .then(DB => {
                            db = DB;
                            // console.warn("Database OPEN");
                            db.executeSql('SELECT 1 FROM approvedProjectsList LIMIT 1').then(() => {
                                // console.warn("Database is ready ... executing query ...");
                            }).catch((error) => {
                                // console.warn("Received error: ", error);
                                console.log("Database not yet ready ... populating data");
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS approvedProjectsList (idea_id,emp_id,idea_title,' +
                                        'releaseOwner,taskStatus,count,id,taskscount,acceptedDate,userName)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                            });
                            resolve(db);
                        })
                        .catch(error => {
                            console.warn(error);
                        });
                })
                .catch(error => {
                    console.warn("echoTest failed - plugin not functional");
                });
        });
    };

    //Close DataBase
    closeDatabase(db) {
        if (db) {
            console.log("Closing DB");
            db.close()
                .then(status => {
                    console.log("Database CLOSED");
                })
                .catch(error => {
                    this.errorCB(error);
                });
        } else {
            console.log("Database was not OPENED");
        }
    };

    //Add ApprovedProjectsList Data
    addApprovedProjectsListOffline(approved) {
        //   console.warn(profile.empid)
        let array = approved
        this.deleteApprovedProjectsListOffline();
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    array.forEach(approved => {
                        tx.executeSql('INSERT INTO approvedProjectsList VALUES (?, ?, ?, ?, ? ,?, ?, ? ,?, ?)', [
                            approved.idea_id, approved.emp_id, approved.idea_title, approved.releaseOwner, approved.taskStatus,
                            approved.count, approved.id, approved.taskscount, approved.acceptedDate, approved.userName
                        ]).then(([tx, results]) => {
                            resolve(results);
                            console.warn("success")
                        });
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting ApprovedProjectsList Details 
    getApprovedProjectsListOffline() {
        console.warn("Query strated");
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM approvedProjectsList', []).then(([tx, results]) => {
                        console.warn("Query completed");
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { idea_id, emp_id, idea_title, releaseOwner, taskStatus, count, id, taskscount, acceptedDate, userName } = row;
                            profile.push({
                                idea_id, emp_id, idea_title, releaseOwner, taskStatus, count, id, taskscount, acceptedDate, userName
                            });
                        }
                        console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete ApprovedProjectsList
    deleteApprovedProjectsListOffline() {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM approvedProjectsList', []).then(([tx, results]) => {
                        console.warn("deleted" + results);
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

}